Changelog
=========

0.5 (2014-06-19)
----------------
- Fixed the search template in order to be able to use the Plone AJAX calls. [davidjonas]
- Added hardcoded filters for the Thema's sections in the search template. [davidjonas]
- LESS for the new filters. [davidjonas]
- Fixed image size and alignment on homepage. [davidjonas]
- Various minor CSS fixes. [davidjonas]


0.4 (2014-05-12)
----------------

- Nothing changed yet.


0.3 (2014-05-07)
----------------

- Nothing changed yet.


0.2 (2014-05-05)
----------------

- Nothing changed yet.


0.1 (2014-04-25)
----------------

- Initial release
